<?php

##############################################
##                                          ##
##             twitter oauth                ##
##                                          ##
##############################################

require_once 'twitter/EpiCurl.php';
require_once 'twitter/EpiOAuth.php';
require_once 'twitter/EpiTwitter.php';

##############################################
##                                          ##
##             plugin stuff                 ##
##                                          ##
##############################################

define ( 'BP_TWEETSTREAM_VERSION', '1.2.1' );
define ( 'BP_TWEETSTREAM_IS_INSTALLED', 1 );

##############################################
##                                          ##
##             local language               ##
##                                          ##
##############################################

add_action('plugins_loaded', 'tweetstream_textdomain', 9);

function tweetstream_textdomain() {
    $locale = apply_filters( 'tweetstream_textdomain', get_locale() );
    $mofile = WP_PLUGIN_DIR . "/tweetstream/languages/$locale.mo";

    if ( file_exists( $mofile ) ){
        load_textdomain( 'tweetstream_lang', $mofile );
    }
}

################################################
##                                            ##
##  add extra filter option in dropdown       ##
##                                            ##
################################################

add_action('bp_activity_filter_options', 'tweetstream_addFilter',1);
add_action('bp_member_activity_filter_options', 'tweetstream_addFilter',1);

function tweetstream_addFilter() {
    echo '<option value="tweet">'.__( 'Show Tweets', 'tweetstream_lang' ).'</option>';
}

################################################
##                                            ##
##  add action to add checkbox to update form ##
##                                            ##
################################################

add_action ('bp_activity_post_form_options', 'tweetstream_addCheckbox');

//add twitter checkbox to form
function tweetstream_addCheckbox() {

    global $bp;
    $user_id = $bp->loggedin_user->id;
    tweetstream_checkTwitterAuth($user_id);

    if(get_site_option("tweetstream_consumer_key")){

        if(get_usermeta ( $user_id, 'tweetstream_token' )){

            //add css and js
            echo'<script type="text/javascript" src="'.plugins_url("tweetstream/js/tweetstream.js").'"></script>';

            $checkbox_on = get_usermeta ( $user_id, 'tweetstream_checkboxon' );

            if($checkbox_on==1){
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="activity_to_twitter" id="activity_to_twitter" value="1" checked> '.__( 'To twitter', 'tweetstream_lang' ).'</div>';
            }else{
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="activity_to_twitter" id="activity_to_twitter" value="1"> '.__( 'To twitter', 'tweetstream_lang' ).'</div>';
            }

        }else{
            if(get_site_option('tweetstream_user_settings_message')==1){
                echo ' <i>'.__( 'Want to tweet this message to? Check your ', 'tweetstream_lang' ).'<a href="'.$bp->loggedin_user->domain.'settings/tweetstream">'.__( 'tweetstream settings', 'tweetstream_lang' ).'</a>.</i>';
            }
        }
    }
}

################################################
##                                            ##
##  add action to add checkbox to forum form  ##
##                                            ##
################################################

add_action ('groups_forum_new_topic_after', 'tweetstream_addTopicCheckbox' );
add_action ('bp_after_group_forum_post_new', 'tweetstream_addTopicCheckbox' );

//add twitter checkbox to form
function tweetstream_addTopicCheckbox() {
    global $bp;

    $user_id = $bp->loggedin_user->id;
    tweetstream_checkTwitterAuth($user_id);

    if(get_site_option("tweetstream_consumer_key")){

        if(get_usermeta ( $user_id, 'tweetstream_token' )){

            //add css and js
            echo'<script type="text/javascript" src="'.plugins_url("tweetstream/js/tweetstream.js").'"></script>';

            $checkbox_on = get_usermeta ( $user_id, 'tweetstream_checkboxon' );

            if($checkbox_on==1){
                echo'<br><br><div class="tweetstream_checkbox_container"><input type="checkbox" name="topic_to_twitter" id="topic_to_twitter" value="1" checked> '.__( 'To twitter', 'tweetstream_lang' ).'</div>';
            }else{
                echo'<br><br><div class="tweetstream_checkbox_container"><input type="checkbox" name="topic_to_twitter" id="topic_to_twitter" value="1"> '.__( 'To twitter', 'tweetstream_lang' ).'</div>';
            }

        }else{
            if(get_site_option('tweetstream_user_settings_message')==1){
                echo ' <i>'.__( 'Want to tweet this message to? Check your ', 'tweetstream_lang' ).'<a href="'.$bp->loggedin_user->domain.'settings/tweetstream">'.__( 'tweetstream settings', 'tweetstream_lang' ).'</a>.</i>';
            }
        }
    }
}

#################################################
##                                             ##
##  add action to add checkbox to forum reply  ##
##                                             ##
#################################################

add_action ('groups_forum_new_reply_after', 'tweetstream_addTopicReplyCheckbox' );

//add twitter checkbox to form
function tweetstream_addTopicReplyCheckbox() {
    global $bp;

    $user_id = $bp->loggedin_user->id;
    tweetstream_checkTwitterAuth($user_id);

    if(get_site_option("tweetstream_consumer_key")){

        if(get_usermeta ( $user_id, 'tweetstream_token' )){

            //add css and js
            echo'<link rel="stylesheet" href="'.plugins_url("tweetstream/css/style.css").'" type="text/css" media="screen" />';
            echo'<script type="text/javascript" src="'.plugins_url("tweetstream/js/tweetstream.js").'"></script>';

            $checkbox_on = get_usermeta ( $user_id, 'tweetstream_checkboxon' );

            if($checkbox_on==1){
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="topicreply_to_twitter" id="topicreply_to_twitter" value="1" checked> '.__( 'To twitter', 'tweetstream_lang' ).'</div><br><br>';
            }else{
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="topicreply_to_twitter" id="topicreply_to_twitter" value="1" > '.__( 'To twitter', 'tweetstream_lang' ).'</div><br><br>';
            }

        }else{
            if(get_site_option('tweetstream_user_settings_message')==1){
                echo ' <i>'.__( 'Want to tweet this message to? Check your ', 'tweetstream_lang' ).'<a href="'.$bp->loggedin_user->domain.'settings/tweetstream">'.__( 'tweetstream settings', 'tweetstream_lang' ).'</a>.</i>';
            }
        }
    }
}

##############################################
##                                          ##
##        add tweet when new topic          ##
##                                          ##
##############################################

add_filter( 'group_forum_topic_title_before_save', 'tweetstream_topic');

//function with params from bp_activity_add
function tweetstream_topic() {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;
    $title = $_POST['topic_title'];

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($title,"#TWITTER");
    $title = tweetstream_filterTags($title);


    //twitter tag found
    if($pos>0){
        add_filter('bp_forums_new_topic', 'tweetstream_topicSaveId',9);
    }

    return $title;
}

function tweetstream_topicSaveId($id){
    tweetstream_topicToTwitter($id);
    return $id;
}

function tweetstream_topicToTwitter($id){

    global $bp;

    $topic_info = bp_forums_get_topic_details($id);

    //get loged in user id
    $user_id = $bp->loggedin_user->id;
    $content = $_POST['topic_title'];

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($content,"#TWITTER");
    $content = tweetstream_filterTags($content);

    //we found #TWITTER tag so push it to twitter
    if($pos >0) {

        //filter for url ceation
        $backlink = bp_get_group_permalink( $bp->groups->current_group ) . 'forum/topic/' . $topic_info->topic_slug . '/';

        //create short url
        $backlink = tweetstream_getShortUrl($backlink);

        //make ik small enough for twitter but never shorten the backlink
        $max_length = 113;
        if(strlen($content>$max_length))
        {
            $content = substr($content,0,$max_length);
        }

        $content .= " ".$backlink;
        tweetstream_twitterIt($content);
    }

}


##############################################
##                                          ##
##        add tweet when new reply          ##
##                                          ##
##############################################

add_filter('group_forum_post_text_before_save', 'tweetstream_topicReply',9);

function tweetstream_topicReply() {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    $content = $_POST['reply_text'];
    if($content==""){
        $content = $_POST['post_text'];
    }

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($content,"#TWITTER");
    $content = tweetstream_filterTags($content);

    //twitter tag found
    if($pos>0){
        add_filter('group_forum_post_topic_id_before_save', 'tweetstream_topicReplySaveId',9);
    }

    return $content;
}

function tweetstream_topicReplySaveId($id){

    tweetstream_topicReplyToTwitter($id);
    return $id;
}

function tweetstream_topicReplyToTwitter($id){
    global $bp;

    $topic_info = bp_forums_get_topic_details($id);

    //filter for url ceation
    $backlink = bp_get_group_permalink( $bp->groups->current_group ) . 'forum/topic/' . $topic_info->topic_slug . '/';

    //create short url
    $backlink = tweetstream_getShortUrl($backlink);

    //make ik small enough for twitter but never shorten the backlink
    $max_length = 95;
    if(strlen($content>$max_length))
    {
        $content = substr($topic_info->topic_title,0,$max_length);
    }else{
        $content = $topic_info->topic_title;
    }

    $content = __( 'Just responded to:', 'tweetstream_lang' )." ".$content." ".$backlink;

    tweetstream_twitterIt($content);
}

##############################################
##                                          ##
##        add tweet when new activity       ##
##                                          ##
##############################################

add_filter( 'bp_activity_content_before_save', 'tweetstream_activityToTwitter' );

//function with params from bp_activity_add
function tweetstream_activityToTwitter($content) {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($content,"#TWITTER");
    $content = tweetstream_filterTags($content);

    //we found #TWITTER tag so push it to twitter
    if($pos >0) {
        // out all html
        $tweet_content = strip_tags($content);
        $tweet_content =  stripslashes($tweet_content);

        // how long is the content?
        $lenght_content = strlen($tweet_content);

        //how long is user domain
        if(get_usermeta ( $user_id, 'tweetstream_profilelink' )==1){
            $lenght_userdomain = strlen($bp->loggedin_user->domain)+5;
            $max_length = 140-$lenght_userdomain;
            $tweet_content = substr($tweet_content,0,$max_length);

            if(strlen($tweet_content)>137){
                $tweet_content .="...";
            }

            $tweet_content .= " ".tweetstream_getShortUrl($bp->loggedin_user->domain);

        }else{
            $max_length = 137;
            $tweet_content = substr($tweet_content,0,$max_length);
            if(strlen($tweet_content)>134){
                $tweet_content .="...";
            }
        }

        tweetstream_twitterIt($tweet_content);
    }
    return $content;
}

##############################################
##                                          ##
##  function to send content to twitter     ##
##                                          ##
##############################################

function tweetstream_twitterIt($content) {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    //content related things
    $content = mb_convert_encoding($content, 'HTML-ENTITIES', "UTF-8");
    $content = str_replace("@","",$content);
    $content_len = strlen($content);
    
    //filter for other plugins
    $content = str_replace("#FACEBOOK","",$content);
    $content = str_replace("#TWITTER","",$content);
    $content = str_replace("#MYSPACE","",$content);
    $content = str_replace("#LINKEDIN","",$content);

    //create new twitter instance and login
    $token = get_usermeta ( $user_id, 'tweetstream_token' );
    $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

    if($token && $content_len<141){
        $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
        $twitterObj->setToken($token,$secret);

        $status_update = $twitterObj->post_statusesUpdate(array('status' => $content));
        $tweet_info = $status_update->response;
        return true;
    }else{
        return false;
    }

}

##############################################
##                                          ##
##  add tweets to activity stream           ##
##                                          ##
##############################################

//add_action( 'bp_activity_screen_my_activity', 'tweetstream_getTweets', 9 );
//add_action( 'xprofile_screen_display_profile', 'tweetstream_getTweets', 9 );
//add_action( 'bp_blogs_screen_my_blogs', 'tweetstream_getTweets', 9 );
//add_action( 'bp_activity_screen_friends', 'tweetstream_getTweets', 9 );
//add_action( 'bp_activity_screen_groups', 'tweetstream_getTweets', 9 );
//add_action( 'bp_activity_screen_favorites', 'tweetstream_getTweets', 9 );

function tweetstream_getTweets($user_id='') {

    global $bp,$wpdb;

    //allowed to import at all?
    if(get_site_option('tweetstream_user_settings_syncbp')==0){

        //set user fields
        if(!$user_id){
            $user_id = $bp->displayed_user->id;
            $user_login      = $bp->displayed_user->userdata->user_login;
            $user_fullname   = $bp->displayed_user->fullname;
            $cur_hour = date('dmYH');
        }else{
            $user_data = $wpdb->get_results($wpdb->prepare("SELECT * FROM $wpdb->users WHERE id=$user_id;"));
            $user_login      = $user_data[0]->user_login;
            $user_fullname   = bp_core_get_user_displayname($user_id);
            $cur_hour        = 0;
        }

        //is there a maximum inport
        $max_reached = 0;
        $max_import = get_site_option('tweetstream_user_settings_maximport');
        if($max_import!=''){
            if(get_usermeta($user_id,'tweetstream_daycounter')>=$max_import){
                $max_reached = 1;
            }
            else{
                $max_reached = 0;
            }
        }

        if($max_reached==0){

            //check if user has filled in a twitter
            if (get_usermeta ( $user_id, 'tweetstream_token' )) {

                if(get_usermeta ( $user_id, 'tweetstream_synctoac' )==1){

                    //login
                    $last_update = get_usermeta ( $user_id, 'tweetstream_lastupdate' );

                    //did i do an update this hour already?
                    if ($last_update != $cur_hour) {

                        $token = get_usermeta ( $user_id, 'tweetstream_token' );
                        $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

                        //twitter object
                        $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
                        $twitterObj->setToken($token,$secret);

                        //update screenname (mention)
                        $userInfo = $twitterObj->get_accountVerify_credentials();
                        update_usermeta ( $user_id, 'tweetstream_mention',"@".$userInfo->response['screen_name']);

                        //get users timeline
                        $tweetsObj = $twitterObj->get_statusesUser_timeline();
                        $tweets = $tweetsObj->response;

                        //get admin filters
                        $admin_filter = get_site_option('tweetstream_filter');
                        $admin_filterexplicit = get_site_option('tweetstream_filterexplicit');

                        //get user filters
                        $user_filtergood = get_usermeta ( $user_id, 'tweetstream_filtergood' );
                        $user_filterbad = get_usermeta ( $user_id, 'tweetstream_filterbad' );

                        if ($tweets) {
                            foreach ( $tweets as $tweet ) {

                                //set defaults
                                $filter_pass = 1;
                                $exist 	     = 0;

                                //set tweet_text and filter some stuff out
                                $tweet_text = $tweet['text'];
                                $tweet_text = strip_tags($tweet_text);

                                //create new activity instance
                                $activity = new BP_Activity_Activity();

                                //apply admin filtering
                                if($admin_filter!=""){
                                    $arrAdminFilters = explode(",",$admin_filter);
                                    if($arrAdminFilters){
                                        foreach ($arrAdminFilters as $filter){
                                            $pos_filter = strpos($tweet_text,$filter);
                                            if($pos_filter >0){
                                                if(get_site_option('tweetstream_filter_show')==0){
                                                    $tweet_text = str_replace($filter,"",strtolower($tweet_text));
                                                }
                                            }else{
                                                $filter_pass = 0;
                                            }
                                        }
                                    }
                                }

                                if($admin_filterexplicit!="" && $filter_pass==1){
                                    $arrAdminFiltersExplicit = explode(",",$admin_filterexplicit);
                                    if($arrAdminFiltersExplicit){
                                        foreach ($arrAdminFiltersExplicit as $filter){
                                            $pos_filter = strpos(strtolower($tweet_text),$filter);
                                            if($pos_filter >0){
                                                $filter_pass = 0;
                                            }
                                        }
                                    }
                                }

                                //apply user filtering
                                if($user_filtergood!="" && $filter_pass==1){
                                    $arrGoodFilters = explode(",",$user_filtergood);
                                    if($arrGoodFilters){
                                        foreach ($arrGoodFilters as $filter){
                                            $pos_filter = strpos(strtolower($tweet_text),$filter);
                                            if($pos_filter >0){
                                                $filter_pass = 1;
                                            }else{
                                                $filter_pass = 0;
                                            }

                                        }
                                    }
                                }

                                if($user_filterbad!="" && $filter_pass==1){
                                    $arrBadFilters = explode(",",$user_filterbad);
                                    if($arrBadFilters){
                                        foreach ($arrBadFilters as $filter){
                                            $pos_filter = strpos(strtolower($tweet_text),$filter);
                                            if($pos_filter >0){
                                                $filter_pass = 0;
                                            }
                                        }
                                    }
                                }

                                //mentions filtering
                                if(get_usermeta ($user_id,'tweetstream_filtermentions')==1 && $filter_pass==1){
                                    $pattern = '/[@]+([A-Za-z0-9-_]+)/';
                                    $found_mention = preg_match( $pattern, $tweet_text );

                                    if($found_mention){
                                        $filter_pass = 0;
                                    }
                                }

                                if($filter_pass == 1){

                                    //check if we already have this tweet
                                    $activity_info = bp_activity_get( array( 'filter' => array( 'secondary_id' => $tweet['id'])));
                                    if($activity_info['activities'][0]->id){
                                        $exist =1;
                                    }

                                    $pos_source = strpos($tweet['source'],$bp->root_domain);
                                    if($pos_source>0){
                                        $exist = 1;
                                    }

                                    //new activity!
                                    if ($exist == 0 ) {
                                        //convert tweet time to timestamp
                                        $date_recorded = strtotime($tweet['created_at']);
                                        $date_recorded = gmdate('Y-m-d H:i:s',$date_recorded);

                                        $activity = new BP_Activity_Activity ();
                                        $activity->user_id = $user_id;
                                        $activity->component = "tweetstream";
                                        $activity->type = "tweet";
                                        $activity->action = '<a href="'.$bp->root_domain.'/members/'.$user_login.'/" title="'.$user_login.'">'.$user_fullname.'</a><a href="http://www.twitter.com/' . $tweet['user']['screen_name'] . '"><img src="/wp-content/plugins/tweetstream/twitter-icon.png"></a> '.__( 'posted a', 'tweetstream_lang' ).' <a href="http://www.twitter.com/' . $tweet['user']['screen_name'] . '">'.__( 'tweet', 'tweetstream_lang' ).'</a>:';
                                        $activity->content = $tweet_text;
                                        $activity->primary_link = "";
                                        $activity->secondary_item_id = $tweet['id'];
                                        $activity->date_recorded = $date_recorded;
                                        $activity->hide_sitewide = 0;
                                        $activity->save ();

                                        //update day counter
                                        if(get_usermeta($user_id, 'tweetstream_counterdate' )!=date('d-m-Y'))
                                        {
                                            update_usermeta ((int) $user_id, 'tweetstream_daycounter',0);
                                            update_usermeta ( ( int ) $user_id, 'tweetstream_counterdate',date('d-m-Y'));
                                        }

                                        $cur_counter = get_usermeta ( $user_id, 'tweetstream_daycounter' );
                                        update_usermeta ( ( int ) $user_id, 'tweetstream_daycounter',$cur_counter+1);

                                    }
                                }
                            }
                        }

                        //update last update hour
                        update_usermeta ( ( int ) $user_id, 'tweetstream_lastupdate', attribute_escape ( date ( 'dmyH' ) ) );
                    }
                }
            }
        }
    }
}


##############################################
##                                          ##
##  delete tweet from twitter when deleting ##
##  activity item (if tweetstream)          ##
##                                          ##
##############################################

add_action( 'bp_activity_action_delete_activity', 'tweetstream_deletetweet', 10, 2 );

//function with params from bp_activity_delete
function tweetstream_deleteTweet($activity_id,$user_id) {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    $deletetweet = get_usermeta ( $user_id, 'tweetstream_deletetweet' );

    if($deletetweet==1){
        //get activity details
        $activity = new BP_Activity_Activity( $activity_id );

        //get type component and tweet_id
        $type      = $activity->type ;
        $component = $activity->component;
        $tweet_id  = $activity->secondary_item_id;

        //componement tweetstream and type tweet?
        if($component=="tweetstream" && $type=="tweet"){

            //create new twitter instance and login
            $token = get_usermeta ( $user_id, 'tweetstream_token' );
            $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

            $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
            $twitterObj->setToken($token,$secret);

            $status_delete = $twitterObj->post_statusesDestroy(array('id' => $tweet_id));
            $status_delete->response;

        }
    }
    return true;
}

##############################################
##                                          ##
##      Tweetstream user settings page      ##
##                                          ##
##############################################

function tweetstream_settings_screen() {

    global $bp;

    //security fix
    if($bp->displayed_user->id!=$bp->loggedin_user->id){
        header('location:'.$bp->root_domain);
    }

    add_action( 'bp_template_title', 'tweetstream_settings_screen_title' );
    add_action( 'bp_template_content', 'tweetstream_settings_screen_content' );
    bp_core_load_template( apply_filters( 'bp_core_template_plugin', 'members/single/plugins' ) );
}


function tweetstream_settings_screen_title() {
    __( 'Tweetstream', 'tweetstream_lang' );
}

function tweetstream_settings_screen_content() {

    global $bp;

    $user_id = $bp->loggedin_user->id;

    $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"),get_site_option("tweetstream_consumer_secret"));

    if($_POST){
        update_usermeta ( $user_id, 'tweetstream_deletetweet',$_POST['tweetstream_deletetweet'] );
        update_usermeta ( $user_id, 'tweetstream_checkboxon',$_POST['tweetstream_checkboxon']);
        update_usermeta ( $user_id, 'tweetstream_synctoac',$_POST['tweetstream_synctoac']);
        update_usermeta ( $user_id, 'tweetstream_profilelink',$_POST['tweetstream_profilelink']);
        update_usermeta ( $user_id, 'tweetstream_filtermentions',$_POST['tweetstream_filtermentions']);
        update_usermeta ( $user_id, 'tweetstream_filtergood',$_POST['tweetstream_filtergood']);
        update_usermeta ( $user_id, 'tweetstream_filterbad',$_POST['tweetstream_filterbad']);

        echo' <div id="message" class="updated fade">
				<p>'.__( 'Settings saved', 'tweetstream_lang' ).'</p>
			</div>
		';
    }

    $tweetstream_deletetweet = get_usermeta ( $user_id, 'tweetstream_deletetweet' );
    $tweetstream_checkboxon = get_usermeta ( $user_id, 'tweetstream_checkboxon' );
    $tweetstream_synctoac = get_usermeta ( $user_id, 'tweetstream_synctoac' );
    $tweetstream_profilelink = get_usermeta ( $user_id, 'tweetstream_profilelink' );
    $tweetstream_filtermentions = get_usermeta ( $user_id, 'tweetstream_filtermentions' );
    $tweetstream_filtergood = get_usermeta ( $user_id, 'tweetstream_filtergood' );
    $tweetstream_filterbad = get_usermeta ( $user_id, 'tweetstream_filterbad' );

    //$token = $twitterObj->getRequestToken(); echo "<pre>"; print_r($token->oauth_token); echo "</pre>";

    if(get_usermeta ( $user_id, 'tweetstream_token' )){

        echo '<form id="settings_form" action="'.$bp->loggedin_user->domain.'settings/tweetstream/" method="post">
        <h3>'.__( 'Tweetstream setting', 'tweetstream_lang' ).'</h3>
        ';
        echo '<b>'.__( 'Permission', 'tweetstream_lang' ).'</b><br>'.__( 'You already gave permission.', 'tweetstream_lang' ).'<br/> '.__( 'To disallow click the button below and choose "Deny"', 'tweetstream_lang' ).'</b><br><br>';

			?>
		
		<a href="<?php echo $twitterObj->getAuthorizationUrl();?>"><input type="button" value="<?php echo __( 'Authorize with twitter', 'tweetstream_lang' );?>"></a><br/><br/>
		
		<table id="activity-notification-settings" class="notification-settings" >
    		<tr class="alt">
    			<th class="icon"></th>
    			<th class="title"><?php echo __( 'Options', 'tweetstream_lang' );?></th>
    			<th class="yes"><?php echo __( 'Yes', 'tweetstream_lang' );?></th>
    			<th class="no"><?php echo __( 'No', 'tweetstream_lang' );?></th>
    		</tr>
    
    		<tr>
    			<td></td>
    			<td><?php echo __( 'Delete tweet from twitter when deleted in activity.', 'tweetstream_lang' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_deletetweet" id="tweetstream_deletetweet" value="1" <?php if($tweetstream_deletetweet==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_deletetweet" id="tweetstream_deletetweet" value="0" <?php if($tweetstream_deletetweet==0){echo'checked';}?>></td>
    		</tr>
    		
    		
    		<?php  if(get_site_option('tweetstream_user_settings_syncbp')==0){ ?>
    		
    		<tr class="alt">
    			<td></td>
    			<td><?php echo __( 'Always check checkbox "To twitter"'  , 'tweetstream_lang' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_checkboxon" id="tweetstream_checkboxon" value="1" <?php if($tweetstream_checkboxon==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_checkboxon" id="tweetstream_checkboxon" value="0" <?php if($tweetstream_checkboxon==0){echo'checked';}?>></td>
    		</tr>
    		
    		<tr>
    			<td></td>
    			<td><?php echo __( 'Synchronize tweets to my activity'  , 'tweetstream_lang' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_synctoac" id="tweetstream_synctoac" value="1" <?php if($tweetstream_synctoac==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_synctoac" id="tweetstream_synctoac" value="0" <?php if($tweetstream_synctoac==0){echo'checked';}?>></td>
    		</tr>
    		
    		<tr class="alt">
    			<td></td>
    			<td><?php echo __( 'Import tweets containing @names' , 'tweetstream_lang' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_filtermentions" id="tweetstream_filtermentions" value="0" <?php if($tweetstream_filtermentions==0){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_filtermentions" id="tweetstream_filtermentions" value="1" <?php if($tweetstream_filtermentions==1){echo'checked';}?>></td>
    		</tr>
    
    		<?php } ?>
    		
    		<tr>
    			<td></td>
    			<td><?php echo __( 'Add my profile link after my tweet'  , 'tweetstream_lang' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_profilelink" id="tweetstream_profilelink" value="1" <?php if($tweetstream_profilelink==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_profilelink" id="tweetstream_profilelink" value="0" <?php if($tweetstream_profilelink==0){echo'checked';}?>></td>
    		</tr>
		</table>
		
		
		<?php  if(get_site_option('tweetstream_user_settings_syncbp')==0){ ?>
		
		<b><?php echo __( 'Filters', 'tweetstream_lang' );?></b><br/>
		<?php echo __( 'With filter you can decide what will be imported and what not. ', 'tweetstream_lang' );?><br/>
		<?php echo __( 'By adding words in the "Good" filter only tweets with those words in it will be imported.', 'tweetstream_lang' );?><br/>
		<?php echo __( 'By adding words in the "Bad" filter tweets with those words won\'t be imported.', 'tweetstream_lang' );?><br/>
		
		<br/>
			
		<table id="activity-notification-settings" class="notification-settings" >
    		<tr>
    			<th><?php echo __( 'Filters (tweets to activity)', 'tweetstream_lang' );?></th>
    			<th></th>
    			<th></th>
    		</tr>
        
    	<tr>
        	<td></td>
        	<td><?php echo __( 'Good filter (comma seperated)', 'tweetstream_lang' );?></td>
        	<td><input type="text" name="tweetstream_filtergood" value="<?php echo $tweetstream_filtergood ;?>" size="50"/></td>
        </tr>
        
        <tr class="alt">
        	<td></td>
            <td><?php echo __( 'Bad filter (comma seperated)', 'tweetstream_lang' );?></td>
            <td><input type="text" name="tweetstream_filterbad" value="<?php echo $tweetstream_filterbad ;?>" size="50"/></td>
        </tr>
	</table>
				
	<?php } ?>
	
			<input type="submit" value="<?php echo __( 'Save settings', 'tweetstream_lang' );?>">
			
			<?php

			echo '</form>';
    }else{
        echo'<b>'.__( 'Permission', 'tweetstream_lang' ).'</b><br>'.__( 'You can setup your tweetstream over here.', 'tweetstream_lang' ).'<br>
			'.__( 'Before u can see al settings please authorize on twitter, to do so click on the link below.', 'tweetstream_lang' ).'<br><br>';
        echo'<a href="'.$twitterObj->getAuthorizationUrl().'"><input type="button" value="'. __( 'Authorize with twitter', 'tweetstream_lang' ).'"></a><br/><br/>';
    }
}

##############################################
##                                          ##
##             setup navigation             ##
##                                          ##
##############################################

function tweetstream_setup_nav() {
    global $bp;

    if(get_site_option("tweetstream_consumer_key")){
        bp_core_new_subnav_item( array ('name' => __ ( 'Tweetstream', 'tweetstream_lang' ), 'slug' => 'tweetstream', 'parent_url' => $bp->loggedin_user->domain . 'settings/', 'parent_slug' => 'settings', 'screen_function' => 'tweetstream_settings_screen', 'position' => 40 ) );
    }
}

add_action ( 'plugins_loaded', 'tweetstream_setup_nav' );

##############################################
##                                          ##
##               admin page                 ##
##                                          ##
##############################################

add_action('admin_menu', 'tweetstream_admin');

function tweetstream_admin() {
    if(is_admin()){
        add_menu_page(__( 'Tweetstream plugin settings', 'tweetstream_lang'), 'Tweetstream', 'administrator', __FILE__, 'tweetstream_settings',plugins_url('images/icon-small.png', __FILE__));
    }
}

function tweetstream_settings() {
    global $bp,$wpdb;

    if($_POST){

        update_site_option( 'tweetstream_filter',trim(strip_tags(strtolower($_POST['tweetstream_filter']))));
        update_site_option( 'tweetstream_filter_show',trim(strip_tags($_POST['tweetstream_filter_show'])));
        update_site_option( 'tweetstream_consumer_key',trim(strip_tags($_POST['tweetstream_consumer_key'])));
        update_site_option( 'tweetstream_consumer_secret',trim(strip_tags($_POST['tweetstream_consumer_secret'])));
        update_site_option( 'tweetstream_user_settings_message',trim(strip_tags($_POST['tweetstream_user_settings_message'])));
        update_site_option( 'tweetstream_filterexplicit',trim(strip_tags(strtolower($_POST['tweetstream_filterexplicit']))));
        update_site_option( 'tweetstream_user_settings_syncbp',trim(strip_tags(strtolower($_POST['tweetstream_user_settings_syncbp']))));
        update_site_option( 'tweetstream_user_settings_maximport',trim(strip_tags(strtolower($_POST['tweetstream_user_settings_maximport']))));

        echo '<div class="updated" style="margin-top:50px;"><p><strong>'.__( 'Settings saved.', 'tweetstream_lang' ).'</strong></p></div>';
    }

?>
<div class="wrap">

<br/><img src="<?php echo plugins_url('images/icon.png', __FILE__);?>" style="float:left;"><h2 style="float:left; line-height:5px; padding-left:5px;"><?php echo __( 'Tweetstream');?></h2><br/>

<form method="post" action="">
    <table class="form-table">
        <?php echo __( '', 'tweetstream_lang' );?>
        <tr>
            <td colspan="2" scope="row">
            <b><?php echo __( 'Twitter API', 'tweetstream_lang' );?></b><br/>

            <?php echo __( 'For the plugin to work you need to get an API key from twitter.', 'tweetstream_lang' );?><br/><br/>
            <?php echo __( 'To get one follow the next steps:', 'tweetstream_lang' );?><br/>
            <?php echo __( '&nbsp;&nbsp;&nbsp;1. Go to ', 'tweetstream_lang' );?>"<a href="http://www.twitter.com/apps" target="_blank">http://www.twitter.com/apps</a>" <?php echo __( ' and login with your twitter account.', 'tweetstream_lang' );?><br/>
            <?php echo __( '&nbsp;&nbsp;&nbsp;2. Create a new app wich has read/write settings, type browser (not client) and a callback url to: ', 'tweetstream_lang' );?><b><?php echo $bp->root_domain;?></b><br/>
            <?php echo __( '&nbsp;&nbsp;&nbsp;3. Fill in the consumer key and consumer secret below.', 'tweetstream_lang' );?><br/>     
            
            </td>
        </tr>
    <tr valign="top">
        <th scope="row"><?php echo __( 'Consumer key:', 'tweetstream_lang' );?></th>
        <td><input type="text" name="tweetstream_consumer_key" value="<?php echo get_site_option('tweetstream_consumer_key'); ?>" size="50"/></td>
        </tr>
         
        <tr valign="top">
        <th scope="row"><?php echo __( 'Consumer secret key:', 'tweetstream_lang' );?></th>
        <td><input type="text" name="tweetstream_consumer_secret" value="<?php echo get_site_option('tweetstream_consumer_secret'); ?>" size="50"/></td>
        </tr>
        
          <tr>
            <td colspan="2">
            <h2><?php echo __( 'Filters (optional)', 'tweetstream_lang' );?></h2><br>
            <?php echo __( 'Filters preventing to get a really messy activity streams.', 'tweetstream_lang' );?><br>
            <?php echo __( 'Example: You have an social network wich focus is on soccer, you don\'t want all tweets of your users showing up that hasn\'t to do anything with soccer.', 'tweetstream_lang' );?><br>
            <?php echo __( 'you can set the filter to "soccer", now only tweets with "soccer" in it will be shown of the users tweets".', 'tweetstream_lang' );?><br>
            <?php echo __( 'By comma seperating words you can set-up multiple filters.', 'tweetstream_lang' );?> (<?php echo __( 'No filter = all tweets.', 'tweetstream_lang' );?>)<br>
            <?php echo __( 'The explicit words filter blocks messages with those words in it.', 'tweetstream_lang' );?>
            
            </td>
        </tr>
        
        <tr valign="top">
        <th scope="row"><?php echo __( 'Filters (comma seperated)', 'tweetstream_lang' );?></th>
        <td><input type="text" name="tweetstream_filter" value="<?php echo get_site_option('tweetstream_filter'); ?>" size="50"/></td>
        </tr>
        
        <tr valign="top">
            <th scope="row"><?php echo __( 'Show filters in tweets.', 'tweetstream_lang' );?></th>
            <th>
            <input type="radio" name="tweetstream_filter_show" id="tweetstream_filter_show" value="1" <?php if(get_site_option('tweetstream_filter_show')==1){echo'checked';}?>> <?php echo __( 'Yes', 'tweetstream_lang' );?>
			<input type="radio" name="tweetstream_filter_show" id="tweetstream_filter_show" value="0" <?php if(get_site_option('tweetstream_filter_show')==0){echo'checked';}?>> <?php echo __( 'No', 'tweetstream_lang' );?>
            </th>
        </tr>
        
        <tr valign="top">
        <th scope="row"><?php echo __( 'Explicit words (comma seperated)', 'tweetstream_lang' );?></th>
        <td><input type="text" name="tweetstream_filterexplicit" value="<?php echo get_site_option('tweetstream_filterexplicit'); ?>" size="50"/></td>
        </tr>
        
        
         <tr valign="top">
        <th scope="row"><h2><?php echo __( 'User options', 'tweetstream_lang' );?></h2></th>
        <td></td>
        </tr>
        
        <tr valign="top">
            <th><?php echo __( 'Show "Want to tweet this message to?..." message on user page.', 'tweetstream_lang' );?></th>
            <th>
            <input type="radio" name="tweetstream_user_settings_message" id="tweetstream_user_settings_message" value="1" <?php if(get_site_option('tweetstream_user_settings_message')==1){echo'checked';}?>> <?php echo __( 'Yes', 'tweetstream_lang' );?>
			<input type="radio" name="tweetstream_user_settings_message" id="tweetstream_user_settings_message" value="0" <?php if(get_site_option('tweetstream_user_settings_message')==0){echo'checked';}?>> <?php echo __( 'No', 'tweetstream_lang' );?>
            </th>
        </tr>
        
        <tr valign="top">
            <th><?php echo __( 'Allow users to sync to buddypress.', 'tweetstream_lang' );?></th>
            <th>
            <input type="radio" name="tweetstream_user_settings_syncbp" id="tweetstream_user_settings_syncbp" value="0" <?php if(get_site_option('tweetstream_user_settings_syncbp')==0){echo'checked';}?>> <?php echo __( 'Yes', 'tweetstream_lang' );?>
			<input type="radio" name="tweetstream_user_settings_syncbp" id="tweetstream_user_settings_syncbp" value="1" <?php if(get_site_option('tweetstream_user_settings_syncbp')==1){echo'checked';}?>> <?php echo __( 'No', 'tweetstream_lang' );?>
            </th>
        </tr>
        
          <tr valign="top">
            <th><?php echo __( 'Max tweet import per user, per day (empty = unlimited).', 'tweetstream_lang' );?></th>
            <th>
           	<input type="text" name="tweetstream_user_settings_maximport" value="<?php echo get_site_option('tweetstream_user_settings_maximport'); ?>" size="5"/>
            </th>
        </tr>
    </table>
    <p class="submit">
    <input type="submit" class="button-primary" value="<?php echo __('Save Changes') ?>" />
    </p>
</form>

<h2><?php echo __( 'Donate', 'tweetstream_lang' );?></h2>

<?php echo __( 'Do do like this plugin? Please donate, so i can stay improving this plugin and give support.', 'tweetstream_lang' );?>
<br/><br/>
<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TKBY4JM6WDSD2" target="_blank"><img src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif"></a>
<br/><br/>

</div>
<?php } 

##############################################
##                                          ##
##          check auth on twitter           ##
##                                          ##
##############################################
function tweetstream_checkTwitterAuth($user_id){

    //do we still have access on twitter? else empty user keys.
    $token = get_usermeta ( $user_id, 'tweetstream_token' );
    $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

    $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
    $twitterObj->setToken($token,$secret);

    $twitterInfo = $twitterObj->get_accountVerify_credentials();
    $twitterInfo = $twitterInfo->responseText;
    $twitterInfo = json_decode($twitterInfo);
    if($twitterInfo->error){
        update_usermeta ( $user_id, 'tweetstream_token','' );
        update_usermeta ( $user_id, 'tweetstream_tokensecret','' );
    }

}

##############################################
##                                          ##
##          oauth back from twitter         ##
##                                          ##
##############################################

add_action('wp','oauthcheck');

function oauthcheck(){
    global $bp;

    if($_GET['oauth_token']){

        $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
        $twitterObj->setToken($_GET['oauth_token']);
        $token = $twitterObj->getAccessToken();
        $twitterObj->setToken($token->oauth_token, $token->oauth_token_secret);
        $twitterInfo= $twitterObj->get_accountVerify_credentials();
        $twitterInfo->response;

        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_token',$token->oauth_token );
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_tokensecret',$token->oauth_token_secret );
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_synctoac',1);

        //redirect to tweetstream settings
        header('location:'.$bp->loggedin_user->domain."settings/tweetstream");
    }

    if($_GET['denied']){

        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_token','');
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_tokensecret','');
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_synctoac','');

        //redirect to tweetstream settings
        header('location:'.$bp->loggedin_user->domain."settings/tweetstream");
    }
}

//filter tags
add_filter('bp_get_activity_latest_update','tweetstream_filterTags',9);
function tweetstream_filterTags($content){
    $content = str_replace("#TWITTER","",$content);
    return $content;
}

##############################################
##                                          ##
##      shorten url functions               ##
##                                          ##
##############################################

function tweetstream_getShortUrl($url){
    global $bp;
    if($url){
        $input = date('dmyhis');
        $index = "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
        $base  = strlen($index);

        for ($t = floor(log($input, $base)); $t >= 0; $t--) {
            $bcp = bcpow($base, $t);
            $a   = floor($input / $bcp) % $base;
            $out = $out . substr($index, $a, 1);
            $input  = $input - ($a * $bcp);
        }

        $shortId = strrev($out);

        update_usermeta ($bp->loggedin_user->id,'tweetstream_'.$shortId,$url);
        $url = $bp->root_domain.'/'.$shortId;

        return $url;
    }else{
        return false;
    }
}

add_action('wp','tweetstream_resolveShortUrl');

function tweetstream_resolveShortUrl($url){

    global $wpdb;

    //resolving hooked to 404
    if(is_404()){
        $short_id = str_replace("/","",$_SERVER['REQUEST_URI']);
        if($short_id){
            $usermeta = $wpdb->get_row("SELECT * FROM {$wpdb->usermeta} WHERE meta_key='tweetstream_".$short_id."'");
            $url = $usermeta->meta_value;
            if($url){
                header('location:'.$url);
            }
        }
    }
}

##############################################
##                                          ##
##             wp_cron stuff                ##
##                                          ##
##############################################

//on plugin activation register cron
register_activation_hook(__FILE__, 'tweetstream_activation');
add_action('tweetstream_cron_event', 'tweetstream_cron');

function tweetstream_activation() {
    wp_schedule_single_event(time()+300, 'tweetstream_cron_event');    
}

function tweetstream_cron() {

    global $wpdb;
    
    // get all usermeta with twitter authorisation
    if(get_site_option('tweetstream_user_settings_syncbp')==0){
        $user_metas = $wpdb->get_results($wpdb->prepare("SELECT * FROM $wpdb->usermeta WHERE meta_key='tweetstream_token';"));
        if($user_metas){
            foreach ($user_metas as $user_meta){
                tweetstream_getTweets($user_meta->user_id);
            }
        }
    }
    wp_schedule_single_event(time()+300, 'tweetstream_cron_event'); 
}

##############################################
##                                          ##
##             styling stuff                ##
##                                          ##
##############################################

add_action('wp_print_styles', 'add_tweetstream_style');

function add_tweetstream_style() {
    $myStyleUrl = WP_PLUGIN_URL . '/tweetstream/css/style.css';
    $myStyleFile = WP_PLUGIN_DIR . '/tweetstream/css/style.css';
    if ( file_exists($myStyleFile) ) {
        wp_register_style('tweetstreamcss', $myStyleUrl);
        wp_enqueue_style( 'tweetstreamcss');
    }
}

?>